meta_package_manager.tests.test_managers module — Meta Package Manager 2.4.0 documentation

# meta_package_manager.tests.test_managers module

class `meta_package_manager.tests.test_managers.` `TestManagerDefinitions`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test the definition of all package managers.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_ascii_id`()

    All package manager IDs should be short ASCII strings.

  `test_number`()

    Check all implemented package managers are accounted for.

  `test_platforms_type`()

    Check that definitions returns supported platforms as a frozenset.

  `test_platforms_values`()

    Check that definitions returns platforms with a registered label.

  `test_cli_path_type`()

    Check that definitions returns the CLI path as a string.

  `test_cli_args_type`()

    Check that definitions returns CLI args as a list.

  `test_cli_type`()

    Check that all methods returning a CLI is a list.

  `test_outdated_type`()

    Check that all outdated operations returns a dict.

class `meta_package_manager.tests.test_managers.` `TestManagerPlatform`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_macos`()
  `test_linux`(*args, **kwargs)
  `test_windows`(*args, **kwargs)